==> layout_form_builder-1.0.46-dev.1.tar.gz: lib/formcomponent/radio_group.dart <==
import 'package:dynamic_widget/dynamic_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_form_builder_ing/flutter_form_builder_ing.dart';
import 'package:layout_form_builder/datalayer/bean/eform_cache.dart';
import 'package:layout_form_builder/datalayer/constant/eform_properties.dart';
import '../util.dart';

class RadioGroup extends StatefulWidget {
  final Map<String, dynamic> fieldProp;
  final ClickListener? listener;

  RadioGroup({Key? key, required this.fieldProp, required this.listener}) : super(key: key);

  @override
  _RadioGroupState createState() => _RadioGroupState();
}

class _RadioGroupState extends State<RadioGroup> {
  @override
  Widget build(BuildContext context) {
    Map<String, dynamic> fp = widget.fieldProp;
    final hint = EFormCache.getFormFieldPropString(context, fp, EFormProperties.PROP_INPUT_HINT, fromValidator: false);
    final optStr = EFormCache.getFormFieldPropString(context, fp, EFormProperties.PROP_OPTIONS, fromValidator: false);
    final inputId = EFormCache.fieldString(fp, EFormProperties.PROP_INPUT_ID);

    final textStyle = EFormCache.getTextStyle();
    final inputDecoration = EFormCache.getInputDecoration(hint: hint);

    return Theme(
        data: new ThemeData(
          primaryColor: HexColor.fromHex("#9599B6"),
          primaryColorDark: HexColor.fromHex("#9599B6"),
        ),
        child: Padding(
          padding: const EdgeInsets.all(5.0),
          child: FormBuilderRadioGroup(
            validator: (val) {
              return _validate(val, context);
            },
            decoration: inputDecoration,
            name: inputId ?? "",
            options: (optStr == null ? '' : optStr)
                .split("@@@")
                .map((optItem) => FormBuilderFieldOption(value: optItem, child: Text(optItem, style: textStyle?.textStyle)))
                .toList(),
            onChanged: (val) {},
            separator: const VerticalDivider(
              width: 10,
              thickness: 5,
              color: Colors.transparent,
            ),
          ),
        ));
  }

  String? _validate(dynamic value, BuildContext context) {
    String? val = value;
    Map<String, dynamic> fp = widget.fieldProp;
    bool compulsory = EFormCache.getFormFieldPropBool(context, fp, EFormProperties.PROP_COMPULSORY, fromValidator: true, defaultValue: false);

    if (compulsory) {
      if (val == null || val.length == 0) {
        return EFormCache.getFormFieldPropString(context, fp, EFormProperties.PROP_COMPULSORY_ERR_MSG, fromValidator: true);
      }
    }
    return null;
  }
}

==> layout_form_builder-1.0.53-dev.1.tar.gz: lib/formcomponent/radio_group.dart <==
import 'package:dynamic_widget/dynamic_widget.dart';
import 'package:flutter/material.dart';
import 'package:flutter_form_builder_ing/flutter_form_builder_ing.dart';
import 'package:layout_form_builder/datalayer/bean/eform_cache.dart';
import 'package:layout_form_builder/datalayer/constant/eform_properties.dart';
import '../util.dart';

class RadioGroup extends StatefulWidget {
  final Map<String, dynamic> fieldProp;
  final ClickListener? listener;

  RadioGroup({Key? key, required this.fieldProp, required this.listener}) : super(key: key);

  @override
  _RadioGroupState createState() => _RadioGroupState();
}

class _RadioGroupState extends State<RadioGroup> {
  @override
  Widget build(BuildContext context) {
    Map<String, dynamic> fp = widget.fieldProp;
    final hint = EFormCache.getFormFieldPropString(context, fp, EFormProperties.PROP_INPUT_HINT, fromValidator: false);
    final optStr = EFormCache.getFormFieldPropString(context, fp, EFormProperties.PROP_OPTIONS, fromValidator: false);
    final inputId = EFormCache.fieldString(fp, EFormProperties.PROP_INPUT_ID);

    final textStyle = EFormCache.getTextStyle();
    final inputDecoration = EFormCache.getInputDecoration(hint: hint);

    final options = (optStr == null ? '' : optStr).split("@@@");

    return Theme(
        data: new ThemeData(
          primaryColor: HexColor.fromHex("#9599B6"),
          primaryColorDark: HexColor.fromHex("#9599B6"),
        ),
        child: Padding(
          padding: const EdgeInsets.all(5.0),
          child: FormBuilderRadioGroup<dynamic>(
            validator: (val) {
              return _validate(val, context);
            },
            decoration: inputDecoration,
            name: inputId ?? "",
            options: List<dynamic>.from(options)
                .map((optItem) => FormBuilderFieldOption(value: optItem, child: Text(optItem, style: textStyle?.textStyle)))
                .toList(),
            onChanged: (val) {

            },
            separator: const VerticalDivider(
              width: 10,
              thickness: 5,
              color: Colors.transparent,
            ),
          ),
        ));
  }

  String? _validate(dynamic value, BuildContext context) {
    String? val = value?.toString();
    Map<String, dynamic> fp = widget.fieldProp;
    bool compulsory = EFormCache.getFormFieldPropBool(context, fp, EFormProperties.PROP_COMPULSORY, fromValidator: true, defaultValue: false);

    if (compulsory) {
      if (val == null || val.length == 0) {
        return EFormCache.getFormFieldPropString(context, fp, EFormProperties.PROP_COMPULSORY_ERR_MSG, fromValidator: true);
      }
    }
    return null;
  }
}
